@@ -8,8 +8,8 @@
 #' @param weight weighting scheme passed to [quanteda::dfm_weight()]. Ignored
 #'   when `engine` is "rsparse".
 #' @param simil_method specifies method to compute similarity between features.
-#'   The value is passed to [quanteda.textstats::textstat_simil()], "cosine" is used
-#'   otherwise.
+#'   The value is passed to [quanteda.textstats::textstat_simil()], "cosine" is
+#'   used otherwise.
 #' @param cache if `TRUE`, save result of SVD for next execution with identical
 #'   `x` and settings. Use the `base::options(lss_cache_dir)` to change the
 #'   location cache files to be save.
@@ -18,10 +18,13 @@
 #' @param verbose show messages if `TRUE`.
 #' @param ... additional argument passed to the SVD engine
 #' @export
-#' @references Watanabe, Kohei. "Measuring News Bias: Russia's Official News
-#'   Agency ITAR-TASS' Coverage of the Ukraine Crisis." European Journal of
-#'   Communication 32, no. 3 (March 20, 2017): 224–41.
-#'   https://doi.org/10.1177/0267323117695735.
+#' @references
+#' Watanabe, Kohei. 2020. "Latent Semantic Scaling: A Semisupervised
+#'   Text Analysis Technique for New Domains and Languages", Communication
+#'   Methods and Measures. \doi{10.1080/19312458.2020.1832976}.
+#' Watanabe, Kohei. 2017. "Measuring News Bias: Russia's
+#'   Official News Agency ITAR-TASS' Coverage of the Ukraine Crisis" European
+#'   Journal of Communication. \doi{10.1177/0267323117695735}.
 #' @examples
 #' \donttest{
 #' library("quanteda")
@@ -85,11 +88,9 @@ textmodel_lss.dfm <- function(x, seeds, terms = NULL, k = 300, slice = NULL,
     }
 
     engine <- match.arg(engine)
-    terms <- expand_terms(terms, featnames(x))
     seeds <- expand_seeds(seeds, featnames(x), verbose)
-
-    term <- unlist(unname(terms))
     seed <- names(unlist(unname(seeds)))
+    term <- expand_terms(terms, featnames(x))
     feat <- union(term, seed)
 
     if (engine %in% c("RSpectra", "irlba", "rsvd")) {
@@ -156,11 +157,9 @@ textmodel_lss.fcm <- function(x, seeds, terms = NULL, w = 50,
         engine <- "rsparse"
     }
 
-    terms <- expand_terms(terms, featnames(x))
     seeds <- expand_seeds(seeds, featnames(x), verbose)
-
-    term <- unlist(unname(terms))
     seed <- names(unlist(unname(seeds)))
+    term <- expand_terms(terms, featnames(x))
     feat <- union(term, seed)
 
     if (engine == "rsparse") {
@@ -214,12 +213,13 @@ build_lss <- function(...) {
 }
 
 expand_terms <- function(terms, features) {
-
-    if (is.null(terms))
-        terms <- features
-    if (!is.character(terms))
-        stop("features must be a character vector\n", call. = FALSE)
-    quanteda::pattern2fixed(terms, features, "glob", FALSE)
+    if (is.null(terms)) {
+        result <- setdiff(features, "")
+    } else {
+        temp <- quanteda::pattern2fixed(terms, features, valuetype = "glob", case_insensitive = FALSE)
+        result <- unlist(unname(temp))
+    }
+    return(result)
 }
 
 expand_seeds <- function(seeds, features, verbose = FALSE) {
@@ -335,8 +335,6 @@ get_seeds <- function(seeds) {
 #' @noRd
 #' @importFrom stats coef
 #' @importFrom utils head
-#' @importFrom quanteda.textmodels as.coefficients_textmodel
-#' @importFrom quanteda.textmodels as.summary.textmodel
 #' @method summary textmodel_lss
 summary.textmodel_lss <- function(object, n = 30L, ...) {
     result <- list(
